@@ -40,11 +40,8 @@
 
 #include <X11/XKBlib.h>
 #include <X11/extensions/XKBstr.h>
-
-#ifdef HAVE_X11_EXTENSIONS_XINPUT_H
 #include <X11/extensions/XInput.h>
 #include <X11/extensions/XIproto.h>
-#endif
 
 #ifdef HAVE_LIBNOTIFY
 #include <libnotify/notify.h>
@@ -94,7 +91,6 @@ static gpointer manager_object = NULL;
 #define d(str)          do { } while (0)
 #endif
 
-#ifdef HAVE_X11_EXTENSIONS_XINPUT_H
 static GdkFilterReturn
 devicepresence_filter (GdkXEvent *xevent,
                        GdkEvent  *event,
@@ -154,7 +150,6 @@ set_devicepresence_handler (MsdA11yKeyboardManager *manager)
         if (!gdk_error_trap_pop ())
                 gdk_window_add_filter (NULL, devicepresence_filter, manager);
 }
-#endif
 
 static gboolean
 xkb_enabled (MsdA11yKeyboardManager *manager)
@@ -185,7 +180,7 @@ get_xkb_desc_rec (MsdA11yKeyboardManager *manager)
                 desc->ctrls = NULL;
                 status = XkbGetControls (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), XkbAllControlsMask, desc);
         }
-        gdk_error_trap_pop ();
+        gdk_error_trap_pop_ignored ();
 
         g_return_val_if_fail (desc != NULL, NULL);
         g_return_val_if_fail (desc->ctrls != NULL, NULL);
@@ -392,7 +387,7 @@ set_server_from_settings (MsdA11yKeyboardManager *manager)
         XkbFreeKeyboard (desc, XkbAllComponentsMask, True);
 
         XSync (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), FALSE);
-        gdk_error_trap_pop ();
+        gdk_error_trap_pop_ignored ();
 
         mate_settings_profile_end (NULL);
 }
@@ -1006,9 +1001,7 @@ start_a11y_keyboard_idle_cb (MsdA11yKeyboardManager *manager)
         manager->priv->settings = g_settings_new (CONFIG_SCHEMA);
         g_signal_connect (manager->priv->settings, "changed", G_CALLBACK (keyboard_callback), manager);
 
-#ifdef HAVE_X11_EXTENSIONS_XINPUT_H
-	set_devicepresence_handler (manager);
-#endif
+        set_devicepresence_handler (manager);
 
         /* Save current xkb state so we can restore it on exit
          */
@@ -1073,7 +1066,7 @@ restore_server_xkb_config (MsdA11yKeyboardManager *manager)
                          XkbAllComponentsMask, True);
 
         XSync (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), FALSE);
-        gdk_error_trap_pop ();
+        gdk_error_trap_pop_ignored ();
 
         manager->priv->original_xkb_desc = NULL;
 }
@@ -1085,9 +1078,7 @@ msd_a11y_keyboard_manager_stop (MsdA11yKeyboardManager *manager)
 
         g_debug ("Stopping a11y_keyboard manager");
 
-#ifdef HAVE_X11_EXTENSIONS_XINPUT_H
         gdk_window_remove_filter (NULL, devicepresence_filter, manager);
-#endif
 
         if (p->status_icon)
                 gtk_status_icon_set_visible (p->status_icon, FALSE);
@@ -1115,76 +1106,11 @@ msd_a11y_keyboard_manager_stop (MsdA11yKeyboardManager *manager)
         p->stickykeys_shortcut_val = FALSE;
 }
 
-static void
-msd_a11y_keyboard_manager_set_property (GObject        *object,
-                                        guint           prop_id,
-                                        const GValue   *value,
-                                        GParamSpec     *pspec)
-{
-        MsdA11yKeyboardManager *self;
-
-        self = MSD_A11Y_KEYBOARD_MANAGER (object);
-
-        switch (prop_id) {
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
-static void
-msd_a11y_keyboard_manager_get_property (GObject        *object,
-                                        guint           prop_id,
-                                        GValue         *value,
-                                        GParamSpec     *pspec)
-{
-        MsdA11yKeyboardManager *self;
-
-        self = MSD_A11Y_KEYBOARD_MANAGER (object);
-
-        switch (prop_id) {
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
-static GObject *
-msd_a11y_keyboard_manager_constructor (GType                  type,
-                                       guint                  n_construct_properties,
-                                       GObjectConstructParam *construct_properties)
-{
-        MsdA11yKeyboardManager      *a11y_keyboard_manager;
-        MsdA11yKeyboardManagerClass *klass;
-
-        klass = MSD_A11Y_KEYBOARD_MANAGER_CLASS (g_type_class_peek (MSD_TYPE_A11Y_KEYBOARD_MANAGER));
-
-        a11y_keyboard_manager = MSD_A11Y_KEYBOARD_MANAGER (G_OBJECT_CLASS (msd_a11y_keyboard_manager_parent_class)->constructor (type,
-                                                                                                      n_construct_properties,
-                                                                                                      construct_properties));
-
-        return G_OBJECT (a11y_keyboard_manager);
-}
-
-static void
-msd_a11y_keyboard_manager_dispose (GObject *object)
-{
-        MsdA11yKeyboardManager *a11y_keyboard_manager;
-
-        a11y_keyboard_manager = MSD_A11Y_KEYBOARD_MANAGER (object);
-
-        G_OBJECT_CLASS (msd_a11y_keyboard_manager_parent_class)->dispose (object);
-}
-
 static void
 msd_a11y_keyboard_manager_class_init (MsdA11yKeyboardManagerClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-        object_class->get_property = msd_a11y_keyboard_manager_get_property;
-        object_class->set_property = msd_a11y_keyboard_manager_set_property;
-        object_class->constructor = msd_a11y_keyboard_manager_constructor;
-        object_class->dispose = msd_a11y_keyboard_manager_dispose;
         object_class->finalize = msd_a11y_keyboard_manager_finalize;
 
         g_type_class_add_private (klass, sizeof (MsdA11yKeyboardManagerPrivate));
